==> worker_2.9.0.orig.tar.gz: worker-2.9.0/src/showdircacheop.cc <==
/* dirsizeop.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: showdircacheop.cc,v 1.4 2004/10/27 21:09:13 ralf Exp $ */

#include "showdircacheop.h"
#include "listermode.h"
#include "normalmode.h"
#include "worker.h"

const char *ShowDirCacheOp::name = "ShowDirCacheOp";

ShowDirCacheOp::ShowDirCacheOp() : FunctionProto()
{
}

ShowDirCacheOp::~ShowDirCacheOp()
{
}

ShowDirCacheOp*
ShowDirCacheOp::duplicate() const
{
  ShowDirCacheOp *ta=new ShowDirCacheOp();
  return ta;
}

bool
ShowDirCacheOp::isName( const char *str )
{
  if ( strcmp( str, name ) == 0 ) return true; else return false;
}

const char *
ShowDirCacheOp::getName()
{
  return name;
}

int
ShowDirCacheOp::run( ActionMessage *msg )
{
  ListerMode *lm1;
  am=msg;
  if(msg->mode!=msg->AM_MODE_DNDACTION) {
    Lister *l1=msg->getWorker()->getActiveLister();
    if(l1!=NULL) {
      lm1 = l1->getActiveMode();
      if(lm1!=NULL)
        if(lm1->isType("NormalMode")==true) {
          ((NormalMode*)lm1)->showCacheList();
        }
    }
  }
  return 0;
}

const char *
ShowDirCacheOp::getDescription()
{
  return catalog.getLocaleCom( 45 );
}

==> worker_2.11.1.orig.tar.gz: worker-2.11.1/src/showdircacheop.cc <==
/* dirsizeop.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: showdircacheop.cc,v 1.5 2005/10/19 18:00:18 ralf Exp $ */

#include "showdircacheop.h"
#include "listermode.h"
#include "normalmode.h"
#include "worker.h"

const char *ShowDirCacheOp::name = "ShowDirCacheOp";

ShowDirCacheOp::ShowDirCacheOp() : FunctionProto()
{
}

ShowDirCacheOp::~ShowDirCacheOp()
{
}

ShowDirCacheOp*
ShowDirCacheOp::duplicate() const
{
  ShowDirCacheOp *ta=new ShowDirCacheOp();
  return ta;
}

bool
ShowDirCacheOp::isName( const char *str )
{
  if ( strcmp( str, name ) == 0 ) return true; else return false;
}

const char *
ShowDirCacheOp::getName()
{
  return name;
}

int
ShowDirCacheOp::run( WPUContext *wpu, ActionMessage *msg )
{
  ListerMode *lm1;
  if(msg->mode!=msg->AM_MODE_DNDACTION) {
    Lister *l1=msg->getWorker()->getActiveLister();
    if(l1!=NULL) {
      lm1 = l1->getActiveMode();
      if(lm1!=NULL)
        if(lm1->isType("NormalMode")==true) {
          ((NormalMode*)lm1)->showCacheList();
        }
    }
  }
  return 0;
}

const char *
ShowDirCacheOp::getDescription()
{
  return catalog.getLocaleCom( 45 );
}
